package
Version:
v0.0.0-...-6b20bf8
Opens a new window with list of versions in this module.
Published: Jan 15, 2019
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Store struct {
Endpoints []string
}
Store implements kvstore.Store using a Etcd K/V store.
Delete implements kvstore.Store.Delete
Get implements kvstore.Store.Get
Put implements kvstore.Store.Put
Source Files
¶
Click to show internal directories.
Click to hide internal directories.